@@ -75,7 +75,7 @@ class _MainUI():
     def destroy( self ):
         if self.iru is not None:
             self.iru.vid_release()
-        self.mainui.root.destroy()
+        exit()
 
 # SHOW_FRAME FUNCTIONS 
 ###############################################################################
